﻿using SecuritySystemListImplement.Models;
using SecuritySystemContracts.BindingModels;
using SecuritySystemContracts.SearchModels;
using SecuritySystemContracts.StoragesContracts;
using SecuritySystemContracts.ViewModels;

using SecuritySystemListImplement;

namespace SecuritySystemListImplement.Implements
{
    public class OrderStorage : IOrderStorage
    {
        private readonly DataListSingleton _source;
        public OrderStorage()
        {
            _source = DataListSingleton.GetInstance();
        }
        public List<OrderViewModel> GetFullList()
        {
            var result = new List<OrderViewModel>();
            foreach (var Order in _source.Orders)
            {
                result.Add(Order.GetViewModel);
            }
            return result;
        }
        public List<OrderViewModel> GetFilteredList(OrderSearchModel model)
        {
            var result = new List<OrderViewModel>();
            if (model == null)
            {
                return result;
            }
            foreach (var Order in _source.Orders)
            {
                if (Order.Id == model.Id)
                {
                    result.Add(Order.GetViewModel);
                }
            }
            return result;
        }
        public OrderViewModel? GetElement(OrderSearchModel model)
        {
            if (!model.Id.HasValue)
            {
                return null;
            }
            foreach (var Order in _source.Orders)
            {
                if (model.Id.HasValue && Order.Id == model.Id)
                {
                    return Order.GetViewModel;
                }
            }
            return null;
        }
        public OrderViewModel? Insert(OrderBindingModel model)
        {
            model.Id = 1;
            foreach (var Order in _source.Orders)
            {
                if (model.Id <= Order.Id)
                {
                    model.Id = Order.Id + 1;
                }
            }
            var newOrder = Order.Create(model);
            if (newOrder == null)
            {
                return null;
            }
            _source.Orders.Add(newOrder);
            return newOrder.GetViewModel;
        }
        public OrderViewModel? Update(OrderBindingModel model)
        {
            foreach (var Order in _source.Orders)
            {
                if (Order.Id == model.Id)
                {
                    Order.Update(model);
                    return Order.GetViewModel;
                }
            }
            return null;
        }
        public OrderViewModel? Delete(OrderBindingModel model)
        {
            for (int i = 0; i < _source.Orders.Count; ++i)
            {
                if (_source.Orders[i].Id == model.Id)
                {
                    var element = _source.Orders[i];
                    _source.Orders.RemoveAt(i);
                    return element.GetViewModel;
                }
            }
            return null;
        }
        private OrderViewModel AttachSecureName(OrderViewModel model)
        {
            foreach (var secure in _source.Securies)
            {
                if (secure.Id == model.SecureId)
                {
                    model.SecureName = secure.SecureName;
                    return model;
                }
            }
            return model;
        }

    }
}
